from abcli import DESCRIPTION as abcli_DESCRIPTION
from articraft import DESCRIPTION as articraft_DESCRIPTION
from blue_stability import DESCRIPTION as blue_stability_DESCRIPTION
from hubblescope import DESCRIPTION as hubble_DESCRIPTION
from ferfereh import DESCRIPTION as ferfereh_DESCRIPTION
from gizai import DESCRIPTION as giza_DESCRIPTION
from notebooks_and_scripts import DESCRIPTION as nbs_DESCRIPTION
from openai_commands import DESCRIPTION as openai_commands_DESCRIPTION
from roofAI import DESCRIPTION as roofAI_DESCRIPTION
from vancouver_watching import DESCRIPTION as vancouver_watching_DESCRIPTION
from blue_geo import DESCRIPTION as blue_geo_DESCRIPTION

content = {
    "cols": 4,
    "items": {
        "blue-geo": {
            "image": "https://github.com/kamangir/assets/raw/main/nbs/ukraine-timemap/QGIS.png?raw=true",
            "description": blue_geo_DESCRIPTION,
        },
        "notebooks-and-scripts": {
            "image": "https://github.com/kamangir/assets/raw/main/nbs/3x4.jpg?raw=true",
            "description": nbs_DESCRIPTION,
        },
        "vancouver-watching": {
            "image": "https://user-images.githubusercontent.com/1007567/196573547-b1c71b3b-7fac-4d2c-bba0-a87b063830da.png",
            "description": vancouver_watching_DESCRIPTION,
        },
        "giza": {
            "image": "https://github.com/kamangir/giza/raw/main/assets/giza.png",
            "description": giza_DESCRIPTION,
        },
        "roofAI": {
            "image": "https://github.com/kamangir/assets/blob/main/2023-10-28-16-28-36-88493-predict.gif?raw=true",
            "description": roofAI_DESCRIPTION,
        },
        "openai-commands": {
            "image": "https://github.com/kamangir/openai-commands/raw/main/assets/carrot.png",
            "description": openai_commands_DESCRIPTION,
        },
        "hubble": {
            "image": "https://github.com/kamangir/hubble/raw/main/assets/hst/u4ge0106r_c0m.gif",
            "description": hubble_DESCRIPTION,
        },
        "blue-stability": {
            "image": "https://github.com/kamangir/AI-ART/raw/main/blue-stability/blue_stability.gif",
            "description": blue_stability_DESCRIPTION,
        },
        "aiart": {
            "image": "https://github.com/kamangir/openai-commands/raw/main/assets/DALL-E.png?raw=1",
            "description": articraft_DESCRIPTION,
        },
        "awesome-bash-cli": {
            "image": "https://github.com/kamangir/awesome-bash-cli/raw/main/assets/marquee.png",
            "description": abcli_DESCRIPTION,
        },
        "ferfereh": {
            "image": "https://user-images.githubusercontent.com/1007567/221448494-d57e08c1-625b-499e-a576-81894f112d6a.jpg",
            "description": ferfereh_DESCRIPTION,
        },
        "Kanata": {
            "image": "https://kamangir-public.s3.ca-central-1.amazonaws.com/Canadians_v11.gif",
            "description": "a multi-screen video feed that is comprised of a matrix of animated faces that slide to the right.",
        },
        "dec82": {
            "image": "https://github.com/kamangir/blue-bracket/raw/main/images/dec82-6.jpg",
            "description": "A wearable Raspberry Pi + Grove / Qwiic + Camera.",
        },
        "blue-rvr": {
            "image": "https://github.com/kamangir/blue-rvr/raw/master/abcli/assets/marquee.jpeg",
            "description": "a bash cli for Sphero RVR SDK - runs deep learning vision models on a Raspberry Pi using Python and TensorFlow.",
        },
        "blue-bracket": {
            "image": "https://github.com/kamangir/blue-bracket/raw/main/images/marquee.jpg",
            "description": "a parametric 3d-printed bracket to build hardware for machine vision & ai on raspberry pi and jetson nano on the edge.",
        },
        "blue-sbc": {
            "image": "https://github.com/kamangir/blue-bracket/raw/main/images/blue3-1.jpg",
            "description": "python + bash bootstrap for edge computing on single board computers.",
        },
        "template": {
            "image": "TBA",
            "description": "TBA",
        },
    },
}
